==> jc-1.4.0.tar.gz: java/net/URL__241.c <==
// final class java.net.URL$1

// class file dependencies
// @dep_class bf29ff960d5ec1d0 java_lang_Class
// @dep_class 26b8d7b7a241db31 java_lang_ClassLoader
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c80f4aedd95be265 java_lang_String
// @dep_class 157d1b002d4e186 java_net_URL__241
// @dep_class fe58a8cfe9b5b994 java_security_PrivilegedAction

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_ClassLoader
// @dep_header java_lang_String
// @dep_header java_net_URL__241
// @dep_header java_security_PrivilegedAction

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/ClassLoader.h"
#include "java/lang/String.h"
#include "java/net/URL__241.h"
#include "java/security/PrivilegedAction.h"

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// void <init>()
//

static _jc_linenum _jc_java_net_URL__241$linenum_table$_init$52f4ad9f2989aeee[];

static const unsigned char _jc_java_net_URL__241$param_ptypes$_init$52f4ad9f2989aeee[] = { 
_JC_TYPE_VOID };

_jc_method _jc_java_net_URL__241$method_info$_init$52f4ad9f2989aeee = {
	.name=			"<init>",
	.signature=		"()V",
	.class=			&_jc_java_net_URL__241$type,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_java_net_URL__241$param_ptypes$_init$52f4ad9f2989aeee,
	.signature_hash=	_JC_JLONG(0x52f4ad9f2989aeee),
	.access_flags=		0,
	.function=		&_jc_java_net_URL__241$method$_init$52f4ad9f2989aeee,
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_java_net_URL__241$linenum_table$_init$52f4ad9f2989aeee
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(java_net_URL__241, _init$52f4ad9f2989aeee);

void
_jc_java_net_URL__241$method$_init$52f4ad9f2989aeee(_jc_env *const env, _jc_java_net_URL__241$object *this)
{
	struct _jc_java_net_URL__241$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(884);				// 0
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public final java.lang.Object run()
//

static _jc_linenum _jc_java_net_URL__241$linenum_table$run$b190d7b16d5785b8[];

static const unsigned char _jc_java_net_URL__241$param_ptypes$run$b190d7b16d5785b8[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_java_net_URL__241$method_info$run$b190d7b16d5785b8 = {
	.name=			"run",
	.signature=		"()Ljava/lang/Object;",
	.class=			&_jc_java_net_URL__241$type,
	.return_type=		&_jc_java_lang_Object$type,
	.param_ptypes=		&_jc_java_net_URL__241$param_ptypes$run$b190d7b16d5785b8,
	.signature_hash=	_JC_JLONG(0xb190d7b16d5785b8),
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_FINAL,
	.function=		&_jc_java_net_URL__241$method$run$b190d7b16d5785b8,
	.vtable_index=		_JC_OFFSETOF(struct _jc_java_net_URL__241$vtable, java_net_URL__241.run$b190d7b16d5785b8) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_java_net_URL__241$linenum_table$run$b190d7b16d5785b8
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(java_net_URL__241, run$b190d7b16d5785b8);

_jc_java_lang_Object$object *
_jc_java_net_URL__241$method$run$b190d7b16d5785b8(_jc_env *const env, _jc_java_net_URL__241$object *this)
{
	struct _jc_java_net_URL__241$object *r0;
	struct _jc_java_lang_ClassLoader$object *r1;

	// Check for stack overflow
	_JC_STACK_OVERFLOW_CHECK(env);

	r0 = this;
	_JC_LINE_NUMBER(887);				// 0
	r1 = _JC_INVOKE_STATIC(env, java_lang_ClassLoader, getSystemClassLoader$9f135795bbcc420b, 0);
	return r1;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_java_net_URL__241$methods[] = {
	&_jc_java_net_URL__241$method_info$_init$52f4ad9f2989aeee,
	&_jc_java_net_URL__241$method_info$run$b190d7b16d5785b8
};

/************************************************************************
 *			      Interface list				*
 ************************************************************************/

// Directly implemented interfaces
static _jc_type *const _jc_java_net_URL__241$interfaces[] = {
	&_jc_java_security_PrivilegedAction$type
};

/************************************************************************
 *			   Interface hash table				*
 ************************************************************************/

#if _JC_IMETHOD_HASHSIZE != 128
#error "_JC_IMETHOD_HASHSIZE has the wrong value (should be 128)"
#endif

// Interface lookup hash table buckets
static _jc_method *_jc_java_net_URL__241$imethod_hash_bucket_56[] = {
	&_jc_java_net_URL__241$method_info$run$b190d7b16d5785b8,
	_JC_NULL
};

// Interface lookup hash table
static _jc_method **_jc_java_net_URL__241$imethod_hash_table[_JC_IMETHOD_HASHSIZE] = {
	[56]=	_jc_java_net_URL__241$imethod_hash_bucket_56
};

// Interface "quick" lookup hash table
static const void *_jc_java_net_URL__241$imethod_quick_table[_JC_IMETHOD_HASHSIZE] = {
	[56]=	&_jc_java_net_URL__241$method$run$b190d7b16d5785b8
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_java_net_URL__241$instanceof_hash_bucket_6[] = {
	&_jc_java_net_URL__241$type,
	_JC_NULL
};
static _jc_type *const _jc_java_net_URL__241$instanceof_hash_bucket_20[] = {
	&_jc_java_security_PrivilegedAction$type,
	_JC_NULL
};
static _jc_type *const _jc_java_net_URL__241$instanceof_hash_bucket_113[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_java_net_URL__241$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[6]=	_jc_java_net_URL__241$instanceof_hash_bucket_6,
	[20]=	_jc_java_net_URL__241$instanceof_hash_bucket_20,
	[113]=	_jc_java_net_URL__241$instanceof_hash_bucket_113
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_java_net_URL__241$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0xbf29ff960d5ec1d0) },
	{ "java/lang/ClassLoader",	_JC_JLONG(0x26b8d7b7a241db31) },
	{ "java/lang/Object",	_JC_JLONG(0x2a7152deee1944f1) },
	{ "java/lang/String",	_JC_JLONG(0xc80f4aedd95be265) },
	{ "java/security/PrivilegedAction",	_JC_JLONG(0xfe58a8cfe9b5b994) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_java_net_URL__241$vtype _jc_java_net_URL__241$type = {
    .type= {
	.name=			"java/net/URL$1",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_FINAL,
	.flags=			_JC_TYPE_REFERENCE,
	.num_interfaces=sizeof(_jc_java_net_URL__241$interfaces) / sizeof(*_jc_java_net_URL__241$interfaces),
	.interfaces=		_jc_java_net_URL__241$interfaces,
	.imethod_hash_table=	_jc_java_net_URL__241$imethod_hash_table,
	.imethod_quick_table=	_jc_java_net_URL__241$imethod_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		12,
		.hash=			_JC_JLONG(0x157d1b002d4e186),
		.source_file=		"URL.java",
		.instance_size=		sizeof(_jc_java_net_URL__241$refs) + sizeof(_jc_java_net_URL__241$object),
		.num_virtual_refs=	0,
		.num_methods=		sizeof(_jc_java_net_URL__241$methods) / sizeof(*_jc_java_net_URL__241$methods),
		.methods=		_jc_java_net_URL__241$methods,
		.instanceof_hash_table=	_jc_java_net_URL__241$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_java_net_URL__241$class_depends) / sizeof(*_jc_java_net_URL__241$class_depends),
		.class_depends=		_jc_java_net_URL__241$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.java_net_URL__241= {
	    .run$b190d7b16d5785b8=
		&_jc_java_net_URL__241$method$run$b190d7b16d5785b8,
	},
    }
};

==> jc-1.4.5.tar.gz: java/net/URL__241.c <==
// final class java.net.URL$1

// class file dependencies
// @dep_class 764eb76bc6714ae3 java_lang_Class
// @dep_class 58c6b9c5ce1fc756 java_lang_ClassLoader
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 195095aa45046bea java_lang_String
// @dep_class ace7ac635b8116b9 java_net_URL__241
// @dep_class fe58a8cfe9b5b994 java_security_PrivilegedAction

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_ClassLoader
// @dep_header java_lang_String
// @dep_header java_net_URL__241
// @dep_header java_security_PrivilegedAction

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/ClassLoader.h"
#include "java/lang/String.h"
#include "java/net/URL__241.h"
#include "java/security/PrivilegedAction.h"

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// void <init>()
//

static _jc_linenum _jc_java_net_URL__241$linenum_table$_init$52f4ad9f2989aeee[];

static const unsigned char _jc_java_net_URL__241$param_ptypes$_init$52f4ad9f2989aeee[] = { 
_JC_TYPE_VOID };

_jc_method _jc_java_net_URL__241$method_info$_init$52f4ad9f2989aeee = {
	.name=			"<init>",
	.signature=		"()V",
	.class=			&_jc_java_net_URL__241$type,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_java_net_URL__241$param_ptypes$_init$52f4ad9f2989aeee,
	.signature_hash=	_JC_JLONG(0x52f4ad9f2989aeee),
	.access_flags=		0,
	.function=		&_jc_java_net_URL__241$method$_init$52f4ad9f2989aeee,
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_java_net_URL__241$linenum_table$_init$52f4ad9f2989aeee
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(java_net_URL__241, _init$52f4ad9f2989aeee);

void _JC_JCNI_ATTR
_jc_java_net_URL__241$method$_init$52f4ad9f2989aeee(_jc_env *const env, _jc_java_net_URL__241$object *this)
{
	struct _jc_java_net_URL__241$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(885);				// 0
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public final java.lang.Object run()
//

static _jc_linenum _jc_java_net_URL__241$linenum_table$run$b190d7b16d5785b8[];

static const unsigned char _jc_java_net_URL__241$param_ptypes$run$b190d7b16d5785b8[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_java_net_URL__241$method_info$run$b190d7b16d5785b8 = {
	.name=			"run",
	.signature=		"()Ljava/lang/Object;",
	.class=			&_jc_java_net_URL__241$type,
	.return_type=		&_jc_java_lang_Object$type,
	.param_ptypes=		&_jc_java_net_URL__241$param_ptypes$run$b190d7b16d5785b8,
	.signature_hash=	_JC_JLONG(0xb190d7b16d5785b8),
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_FINAL,
	.function=		&_jc_java_net_URL__241$method$run$b190d7b16d5785b8,
	.vtable_index=		_JC_OFFSETOF(struct _jc_java_net_URL__241$vtable, java_net_URL__241.run$b190d7b16d5785b8) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_java_net_URL__241$linenum_table$run$b190d7b16d5785b8
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(java_net_URL__241, run$b190d7b16d5785b8);

_jc_java_lang_Object$object * _JC_JCNI_ATTR
_jc_java_net_URL__241$method$run$b190d7b16d5785b8(_jc_env *const env, _jc_java_net_URL__241$object *this)
{
	struct _jc_java_net_URL__241$object *r0;
	struct _jc_java_lang_ClassLoader$object *r1;

	// Check for stack overflow
	_JC_STACK_OVERFLOW_CHECK(env);

	r0 = this;
	_JC_LINE_NUMBER(888);				// 0
	r1 = _JC_INVOKE_STATIC(env, java_lang_ClassLoader, getSystemClassLoader$9f135795bbcc420b, 0);
	return r1;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_java_net_URL__241$methods[] = {
	&_jc_java_net_URL__241$method_info$_init$52f4ad9f2989aeee,
	&_jc_java_net_URL__241$method_info$run$b190d7b16d5785b8
};

/************************************************************************
 *			      Interface list				*
 ************************************************************************/

// Directly implemented interfaces
static _jc_type *const _jc_java_net_URL__241$interfaces[] = {
	&_jc_java_security_PrivilegedAction$type
};

/************************************************************************
 *			   Interface hash table				*
 ************************************************************************/

#if _JC_IMETHOD_HASHSIZE != 128
#error "_JC_IMETHOD_HASHSIZE has the wrong value (should be 128)"
#endif

// Interface lookup hash table buckets
static _jc_method *_jc_java_net_URL__241$imethod_hash_bucket_56[] = {
	&_jc_java_net_URL__241$method_info$run$b190d7b16d5785b8,
	_JC_NULL
};

// Interface lookup hash table
static _jc_method **_jc_java_net_URL__241$imethod_hash_table[_JC_IMETHOD_HASHSIZE] = {
	[56]=	_jc_java_net_URL__241$imethod_hash_bucket_56
};

// Interface "quick" lookup hash table
static const void *_jc_java_net_URL__241$imethod_quick_table[_JC_IMETHOD_HASHSIZE] = {
	[56]=	&_jc_java_net_URL__241$method$run$b190d7b16d5785b8
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_java_net_URL__241$instanceof_hash_bucket_20[] = {
	&_jc_java_security_PrivilegedAction$type,
	_JC_NULL
};
static _jc_type *const _jc_java_net_URL__241$instanceof_hash_bucket_57[] = {
	&_jc_java_net_URL__241$type,
	_JC_NULL
};
static _jc_type *const _jc_java_net_URL__241$instanceof_hash_bucket_101[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_java_net_URL__241$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[20]=	_jc_java_net_URL__241$instanceof_hash_bucket_20,
	[57]=	_jc_java_net_URL__241$instanceof_hash_bucket_57,
	[101]=	_jc_java_net_URL__241$instanceof_hash_bucket_101
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_java_net_URL__241$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0x764eb76bc6714ae3) },
	{ "java/lang/ClassLoader",	_JC_JLONG(0x58c6b9c5ce1fc756) },
	{ "java/lang/Object",	_JC_JLONG(0x1c4f1fc002fc96e5) },
	{ "java/lang/String",	_JC_JLONG(0x195095aa45046bea) },
	{ "java/security/PrivilegedAction",	_JC_JLONG(0xfe58a8cfe9b5b994) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_java_net_URL__241$vtype _jc_java_net_URL__241$type = {
    .type= {
	.name=			"java/net/URL$1",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_FINAL,
	.flags=			_JC_TYPE_REFERENCE,
	.num_interfaces=sizeof(_jc_java_net_URL__241$interfaces) / sizeof(*_jc_java_net_URL__241$interfaces),
	.interfaces=		_jc_java_net_URL__241$interfaces,
	.imethod_hash_table=	_jc_java_net_URL__241$imethod_hash_table,
	.imethod_quick_table=	_jc_java_net_URL__241$imethod_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		12,
		.hash=			_JC_JLONG(0xace7ac635b8116b9),
		.source_file=		"URL.java",
		.instance_size=		sizeof(_jc_java_net_URL__241$refs) + sizeof(_jc_java_net_URL__241$object),
		.num_virtual_refs=	0,
		.num_methods=		sizeof(_jc_java_net_URL__241$methods) / sizeof(*_jc_java_net_URL__241$methods),
		.methods=		_jc_java_net_URL__241$methods,
		.instanceof_hash_table=	_jc_java_net_URL__241$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_java_net_URL__241$class_depends) / sizeof(*_jc_java_net_URL__241$class_depends),
		.class_depends=		_jc_java_net_URL__241$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.java_net_URL__241= {
	    .run$b190d7b16d5785b8=
		&_jc_java_net_URL__241$method$run$b190d7b16d5785b8,
	},
    }
};
